Header

Trait Header 

pub trait Header {
    // Required method
    fn write_header(&self, output: &mut impl Writer, column: usize);
}

Required Methods

fn write_header(&self, output: &mut impl Writer, column: usize)

Writes the header value followed by CRLF. column is the number of bytes already on the current line, normally the header name plus “: “.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors