pub struct MessageBuilder<'x> {
    pub headers: Vec<(Cow<'x, str>, HeaderType<'x>)>,
    pub html_body: Option<MimePart<'x>>,
    pub text_body: Option<MimePart<'x>>,
    pub attachments: Option<Vec<MimePart<'x>>>,
    pub body: Option<MimePart<'x>>,
}
Builds an RFC5322 compliant MIME email message.

Fields

headers: Vec<(Cow<'x, str>, HeaderType<'x>)>html_body: Option<MimePart<'x>>text_body: Option<MimePart<'x>>attachments: Option<Vec<MimePart<'x>>>body: Option<MimePart<'x>>

Implementations

Create a new MessageBuilder.

Set the Message-ID header. If no Message-ID header is set, one will be generated automatically.

Set the In-Reply-To header.

Set the References header.

Set the Sender header.

Set the From header.

Set the To header.

Set the Cc header.

Set the Bcc header.

Set the Reply-To header.

Set the Subject header.

Set the Date header. If no Date header is set, one will be generated automatically.

Add a custom header.

Set custom headers.

Set the plain text body of the message. Note that only one plain text body per message can be set using this function. To build more complex MIME body structures, use the body method instead.

Set the HTML body of the message. Note that only one HTML body per message can be set using this function. To build more complex MIME body structures, use the body method instead.

Add a binary attachment to the message.

Add a text attachment to the message.

Add an inline binary to the message.

Set a custom MIME body structure.

Build the message.

Build message to a Vec.

Build message to a String.